markupsafe: Safely add untrusted strings to HTML/XML markup
===========================================================

Description
-----------

Implements a XML/HTML/XHTML Markup safe string for Python

License
-------

Simplified BSD


Upstream Contact
----------------

Home page: http://github.com/mitsuhiko/markupsafe

